@@ -332,9 +332,9 @@ setCarma<-function(p,
         Model_Carma<-setModel(drift=drift_Carma,
                               diffusion = NULL,
                               hurst=mydots$hurst,
-                              jump.coeff=jump_Carma,
+                              jump.coeff=as.matrix(jump_Carma),
                               measure=eval(mydots$measure),
-                              measure.type=mydots$measure.type,
+                              measure.type=eval(mydots$measure.type),
                               jump.variable=mydots$jump.variable,
                               time.variable=mydots$time.variable,
                               state.variable=c(Carma.var,Y_coeff),
